@@ -1,4 +1,4 @@
-# Copyright 2013-2014 Eucalyptus Systems, Inc.
+# Copyright (c) 2013-2016 Hewlett Packard Enterprise Development LP
 #
 # Redistribution and use of this software in source and binary forms,
 # with or without modification, are permitted provided that the following
@@ -25,15 +25,14 @@
 
 import argparse
 import hashlib
-import socket
 import sys
 import threading
 import time
 
 from requestbuilder import Arg
-from requestbuilder.exceptions import (ArgumentError, ClientError,
-                                       TimeoutError)
+import requestbuilder.exceptions
 from requestbuilder.mixins import FileTransferProgressBarMixin
+import six
 
 from euca2ools.commands.s3 import S3Request
 import euca2ools.util
@@ -72,23 +71,25 @@ class PutObject(S3Request, FileTransferProgressBarMixin):
         S3Request.configure(self)
         if self.args['source'] == '-':
             if self.args.get('size') is None:
-                raise ArgumentError(
+                raise requestbuilder.exceptions.ArgumentError(
                     "argument --size is required when uploading stdin")
             source = _FileObjectExtent(sys.stdin, self.args['size'])
-        elif isinstance(self.args['source'], basestring):
+        elif isinstance(self.args['source'], six.string_types):
             source = _FileObjectExtent.from_filename(
                 self.args['source'], size=self.args.get('size'))
         else:
             if self.args.get('size') is None:
-                raise ArgumentError(
+                raise requestbuilder.exceptions.ArgumentError(
                     "argument --size is required when uploading a file object")
             source = _FileObjectExtent(self.args['source'], self.args['size'])
         self.args['source'] = source
         bucket, _, key = self.args['dest'].partition('/')
         if not bucket:
-            raise ArgumentError('destination bucket name must be non-empty')
+            raise requestbuilder.exceptions.ArgumentError(
+                'destination bucket name must be non-empty')
         if not key:
-            raise ArgumentError('destination key name must be non-empty')
+            raise requestbuilder.exceptions.ArgumentError(
+                'destination key name must be non-empty')
 
     def preprocess(self):
         self.path = self.args['dest']
@@ -101,7 +102,9 @@ class PutObject(S3Request, FileTransferProgressBarMixin):
     def main(self):
         self.preprocess()
         source = self.args['source']
-        self.headers['Content-Length'] = source.size
+
+        # For requests >=2.11.0 it requires headers to be either str or bytes
+        self.headers['Content-Length'] = bytes(source.size)
 
         # We do the upload in another thread so the main thread can show a
         # progress bar.
@@ -130,8 +133,8 @@ class PutObject(S3Request, FileTransferProgressBarMixin):
     def try_send(self, source, retries_left=0):
         self.body = source
         if retries_left > 0 and not source.can_rewind:
-            self.log.warn('source cannot rewind, so requested retries will '
-                          'not be attempted')
+            self.log.notice('source cannot rewind, so requested retries will '
+                            'not be attempted')
             retries_left = 0
         try:
             response = self.send()
@@ -140,9 +143,10 @@ class PutObject(S3Request, FileTransferProgressBarMixin):
             if their_md5 != our_md5:
                 self.log.error('corrupt upload (our MD5: %s, their MD5: %s',
                                our_md5, their_md5)
-                raise ClientError('upload was corrupted during transit')
-        except ClientError as err:
-            if isinstance(err, TimeoutError):
+                raise requestbuilder.exceptions.ClientError(
+                    'upload was corrupted during transit')
+        except requestbuilder.exceptions.ClientError as err:
+            if isinstance(err, requestbuilder.exceptions.TimeoutError):
                 if retries_left > 0:
                     self.log.info('retrying upload (%i retry attempt(s) '
                                   'remaining)', retries_left)
@@ -197,7 +201,7 @@ class _FileObjectExtent(object):
         remaining = self.size - self.__bytes_read
         if remaining <= 0:
             raise StopIteration()
-        chunk = self.fileobj.next()  # might raise StopIteration, which is good
+        chunk = next(self.fileobj)  # might raise StopIteration, which is good
         chunk = chunk[:remaining]  # throw away data that are off the end
         self.__bytes_read += len(chunk)
         self.__md5.update(chunk)
